import * as pulumi from "@pulumi/pulumi";
/**
 * The ``postgresql.Grant`` resource creates and manages privileges given to a user for a database schema.
 *
 * See [PostgreSQL documentation](https://www.postgresql.org/docs/current/sql-grant.html)
 *
 * > **Note:** This resource needs Postgresql version 9 or above.
 * **Note:** Using column & table grants on the _same_ table with the _same_ privileges can lead to unexpected behaviours.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * // Grant SELECT privileges on 2 tables
 * const readonlyTables = new postgresql.Grant("readonly_tables", {
 *     database: "test_db",
 *     role: "test_role",
 *     schema: "public",
 *     objectType: "table",
 *     objects: [
 *         "table1",
 *         "table2",
 *     ],
 *     privileges: ["SELECT"],
 * });
 * // Grant SELECT & INSERT privileges on 2 columns in 1 table
 * const readInsertColumn = new postgresql.Grant("read_insert_column", {
 *     database: "test_db",
 *     role: "test_role",
 *     schema: "public",
 *     objectType: "column",
 *     objects: ["table1"],
 *     columns: [
 *         "col1",
 *         "col2",
 *     ],
 *     privileges: [
 *         "UPDATE",
 *         "INSERT",
 *     ],
 * });
 * ```
 *
 * ## Examples
 *
 * Revoke default accesses for public schema:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const revokePublic = new postgresql.Grant("revoke_public", {
 *     database: "test_db",
 *     role: "public",
 *     schema: "public",
 *     objectType: "schema",
 *     privileges: [],
 * });
 * ```
 */
export declare class Grant extends pulumi.CustomResource {
    /**
     * Get an existing Grant resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: GrantState, opts?: pulumi.CustomResourceOptions): Grant;
    /**
     * Returns true if the given object is an instance of Grant.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Grant;
    /**
     * The columns upon which to grant the privileges. Required when `objectType` is `column`. You cannot specify this option if the `objectType` is not `column`.
     */
    readonly columns: pulumi.Output<string[] | undefined>;
    /**
     * The database to grant privileges on for this role.
     */
    readonly database: pulumi.Output<string>;
    /**
     * The PostgreSQL object type to grant the privileges on (one of: database, schema, table, sequence, function, procedure, routine, foreign_data_wrapper, foreign_server, column).
     */
    readonly objectType: pulumi.Output<string>;
    /**
     * The objects upon which to grant the privileges. An empty list (the default) means to grant permissions on *all* objects of the specified type. You cannot specify this option if the `objectType` is `database` or `schema`. When `objectType` is `column`, only one value is allowed.
     */
    readonly objects: pulumi.Output<string[] | undefined>;
    /**
     * The list of privileges to grant. There are different kinds of privileges: SELECT, INSERT, UPDATE, DELETE, TRUNCATE, REFERENCES, TRIGGER, CREATE, CONNECT, TEMPORARY, EXECUTE, and USAGE. An empty list could be provided to revoke all privileges for this role.
     */
    readonly privileges: pulumi.Output<string[]>;
    /**
     * The name of the role to grant privileges on, Set it to "public" for all roles.
     */
    readonly role: pulumi.Output<string>;
    /**
     * The database schema to grant privileges on for this role (Required except if objectType is "database")
     */
    readonly schema: pulumi.Output<string | undefined>;
    /**
     * Whether the recipient of these privileges can grant the same privileges to others. Defaults to false.
     */
    readonly withGrantOption: pulumi.Output<boolean | undefined>;
    /**
     * Create a Grant resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GrantArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Grant resources.
 */
export interface GrantState {
    /**
     * The columns upon which to grant the privileges. Required when `objectType` is `column`. You cannot specify this option if the `objectType` is not `column`.
     */
    columns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The database to grant privileges on for this role.
     */
    database?: pulumi.Input<string>;
    /**
     * The PostgreSQL object type to grant the privileges on (one of: database, schema, table, sequence, function, procedure, routine, foreign_data_wrapper, foreign_server, column).
     */
    objectType?: pulumi.Input<string>;
    /**
     * The objects upon which to grant the privileges. An empty list (the default) means to grant permissions on *all* objects of the specified type. You cannot specify this option if the `objectType` is `database` or `schema`. When `objectType` is `column`, only one value is allowed.
     */
    objects?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The list of privileges to grant. There are different kinds of privileges: SELECT, INSERT, UPDATE, DELETE, TRUNCATE, REFERENCES, TRIGGER, CREATE, CONNECT, TEMPORARY, EXECUTE, and USAGE. An empty list could be provided to revoke all privileges for this role.
     */
    privileges?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the role to grant privileges on, Set it to "public" for all roles.
     */
    role?: pulumi.Input<string>;
    /**
     * The database schema to grant privileges on for this role (Required except if objectType is "database")
     */
    schema?: pulumi.Input<string>;
    /**
     * Whether the recipient of these privileges can grant the same privileges to others. Defaults to false.
     */
    withGrantOption?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a Grant resource.
 */
export interface GrantArgs {
    /**
     * The columns upon which to grant the privileges. Required when `objectType` is `column`. You cannot specify this option if the `objectType` is not `column`.
     */
    columns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The database to grant privileges on for this role.
     */
    database: pulumi.Input<string>;
    /**
     * The PostgreSQL object type to grant the privileges on (one of: database, schema, table, sequence, function, procedure, routine, foreign_data_wrapper, foreign_server, column).
     */
    objectType: pulumi.Input<string>;
    /**
     * The objects upon which to grant the privileges. An empty list (the default) means to grant permissions on *all* objects of the specified type. You cannot specify this option if the `objectType` is `database` or `schema`. When `objectType` is `column`, only one value is allowed.
     */
    objects?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The list of privileges to grant. There are different kinds of privileges: SELECT, INSERT, UPDATE, DELETE, TRUNCATE, REFERENCES, TRIGGER, CREATE, CONNECT, TEMPORARY, EXECUTE, and USAGE. An empty list could be provided to revoke all privileges for this role.
     */
    privileges: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the role to grant privileges on, Set it to "public" for all roles.
     */
    role: pulumi.Input<string>;
    /**
     * The database schema to grant privileges on for this role (Required except if objectType is "database")
     */
    schema?: pulumi.Input<string>;
    /**
     * Whether the recipient of these privileges can grant the same privileges to others. Defaults to false.
     */
    withGrantOption?: pulumi.Input<boolean>;
}
